pub fn validate_inside_iterator(
name: &Lowercase<'_>,
listtype: ListType,
block: &Block,
data: &Everything,
sc: &mut ScopeContext,
vd: &mut Validator<'_>,
tooltipped: Tooltipped,
)Expand description
This checks the special fields for certain iterators, like type = in every_relation.
It doesn’t check the generic ones like limit or the ordering ones for ordered_*.